using System;
using System.Collections.Generic;
using System.Text;
using Utils.DataBase;
using System.Data;
using PhoenixDLL.Class.Managers;
using PhoenixDLL.Class;
using System.Collections;
using Utils.Logs;

namespace PhoenixCards.Class
{
    /// <summary>
    /// Class which manages the presence of the patients of the today's rendez-vous
    /// </summary>
    public class TimeCardManager
    {
        #region Variables
        /// <summary>
        /// Patient which has meetings today
        /// </summary>
        private PatientManager vPatientManager;
        /// <summary>
        /// Meetings the patient has today
        /// </summary>
        private ArrayList vMeetingManager = new ArrayList();
        /// <summary>
        /// Sql manager
        /// </summary>
        private OleDbSql SqlManager = new OleDbSql(Options.Instance.Path);
        /// <summary>
        /// Indicates whether the patient has meeting today
        /// </summary>
        private bool vHasRendezVous = false;
        #endregion

        #region Constructors
        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="_PatientManager">The patient</param>
        /// <exception cref="ArgumentException">If the ID is negative or does not link a patient</exception>
        public TimeCardManager(PatientManager _PatientManager)
        {
            if (_PatientManager == null || _PatientManager.IDPatient < 0)
                throw new ArgumentException("The ID cannot be negative!");
            vPatientManager = _PatientManager;
            this.CalculateMeetings();
        }
        #endregion

        #region Methods
        /// <summary>
        /// Calculate the meetings the patient has today
        /// </summary>
        private void CalculateMeetings()
        {
            SqlManager.SqlQuery = "SELECT * FROM RendezVous WHERE ID_Patient = " + vPatientManager.IDPatient
                + " AND Debut >= Date() AND Debut < Date() +1 AND came_to_rdv = FALSE AND a_Paye = FALSE;";
            DataSet ds = new DataSet();
            int Rows = SqlManager.ExecuteSql(ref ds);
            if (Rows > 0)
            {
                this.vHasRendezVous = true;
                for (int i = 0; i < ds.Tables[0].Rows.Count; i++)
                {
                    MeetingManager mm = new MeetingManager();
                    mm.Came = (bool)ds.Tables[0].Rows[i]["came_to_rdv"];
                    mm.End = (DateTime)ds.Tables[0].Rows[i]["Fin"];
                    mm.IDMeeting = (int)ds.Tables[0].Rows[i]["id_rdv"];
                    mm.Message = (string)ds.Tables[0].Rows[i]["Message"];
                    mm.Patient = this.PatientManager;
                    mm.Payed = (bool)ds.Tables[0].Rows[i]["a_paye"];
                    mm.Start = (DateTime)ds.Tables[0].Rows[i]["Debut"];
                    mm.Title = (string)ds.Tables[0].Rows[i]["Titre"];
                    vMeetingManager.Add(mm);
                }
            }
            else
                this.vHasRendezVous = false;

        }
        #endregion

        #region Properties
        /// <summary>
        /// Gets or sets the patient which has meetings today
        /// </summary>
        public PatientManager PatientManager
        {
            get { return vPatientManager; }
            set { vPatientManager = value; }
        }
        /// <summary>
        /// Gets the meetings the patient has today
        /// </summary>
        public ArrayList Meetings
        {
            get { return vMeetingManager; }
        }
        /// <summary>
        /// Gets a value wich indicates wheter the patient has rendez-vous today
        /// </summary>
        public bool HasRendezVous { get { return vHasRendezVous; } }
        /// <summary>
        /// Gets the number of missed meetings
        /// </summary>
        /// <returns>The number of lines or -1 if an error occured</returns>
        public int MissedMeetings
        {
            get
            {
                try
                {
                    SqlManager.SqlQuery = "SELECT COUNT(*) FROM RendezVous WHERE id_patient = "
                        + this.vPatientManager.IDPatient + " AND came_to_rdv = FALSE AND Debut < DATE()-1 ;";
                    return (int)SqlManager.ExecuteScalar();
                }
                catch (Exception ex)
                {
                    Log.Instance.Write(ex, this, LogType.Error);
                    return -1;
                }
            }
        }
        #endregion
    }
}
