using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Data.OleDb;
using PhoenixDLL.Class;
using PhoenixDLL.GUI;
using PhoenixDLL.Class.Managers;
using Utils.DataBase;
using Utils.Logs;

namespace PhoenixMoney.GUI
{
    public partial class fr_Main : Form
    {
        #region Variables
        /// <summary>
        /// Dette lors de la selection d'un patient endett
        /// </summary>
        private int vSelectedDebts = 0;
        /// <summary>
        /// ID du payeur de dette
        /// </summary>
        private int vSelectedDebtsSolder = -1;
        /// <summary>
        /// SqlManager
        /// </summary>
        private OleDbSql SqlManager = new OleDbSql(Options.Instance.Path);
        #endregion

        #region Constructeurs
        /// <summary>
        /// Constructeur
        /// </summary>
        public fr_Main()
        {
            InitializeComponent();
            tsMenu_Options.Visible = Options.Instance.OptionsMenuVisible;
            tsMenu_MenuVisible.Checked = Options.Instance.PagaMenu.IsVisible;
            ts_Tools.Visible = Options.Instance.PagaMenu.IsVisible;
            Options.Instance.OptionChanged += new OnOptionChangedHandler(Event_OptionsChanged);
            SetToolStrips();
        }
        #endregion

        #region Events
        #region Frame
        /// <summary>
        /// Chargement de la frame
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Frame_Load(object sender, EventArgs e)
        {            
            RefreshDettes();
        }
        /// <summary>
        /// The frame is focused
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Frame_Enter(object sender, EventArgs e)
        {
            RefreshDettes();            
        }
        #endregion

        #region Menu
        /// <summary>
        /// Menu d'vOptions
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Options(object sender, EventArgs e)
        {
            fr_Options fr = new fr_Options();
            fr.ShowDialog();
        }
        /// <summary>
        /// A Propos
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_APropos(object sender, EventArgs e)
        {
            fr_About fr = new fr_About();
            fr.ShowDialog();
        }
        /// <summary>
        /// Non payed meetings
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_NonPayedHistory(object sender, EventArgs e)
        {
            fr_HistoryNonCameMeeting fr = new fr_HistoryNonCameMeeting();
            fr.FrameUse = FrameUse.UnpayedMeetings;
            fr.Text = "Rendez-vous non pays...";
            fr.ShowDialog();
            RefreshData();
        }
        /// <summary>
        /// Uncame meetings
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_UncameHistory(object sender, EventArgs e)
        {
            fr_HistoryNonCameMeeting fr = new fr_HistoryNonCameMeeting();
            fr.FrameUse = FrameUse.UncameMeetings;
            fr.Text = "Rendez-vous non prests...";
            fr.ShowDialog();
            RefreshData();
        }
        /// <summary>
        /// Click on the managment menu
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_VisibleMenu(object sender, EventArgs e)
        {
            if (tsMenu_MenuVisible.Checked)
            {
                tsMenu_MenuVisible.Checked = false;
                ts_Tools.Visible = false;
                Options.Instance.PagaMenu.IsVisible = false;
            }
            else
            {
                tsMenu_MenuVisible.Checked = true;
                ts_Tools.Visible = true;
                Options.Instance.PagaMenu.IsVisible = true;
            }
        }
        /// <summary>
        /// Close the window
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Quit(object sender, EventArgs e)
        {
            this.Close();
        }
        #endregion

        #region Onglet rendez-vous aujourd'hui
        /// <summary>
        /// Boutton quitter
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_Cancel(object sender, EventArgs e)
        {
            this.Close();
        }
        /// <summary>
        /// Rafraichir les donnes
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MenuClick_Refresh(object sender, EventArgs e)
        {
            RefreshDettes();            
        }
        #endregion

        #region Onglet Dettes
        /// <summary>
        /// Double clique dans le DataGridView des dettes
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void EventDoubleClick_DGV_Dette(object sender, EventArgs e)
        {
            try
            {
                btn_Pay.Text = (string)dgv_Dettes.SelectedRows[0].Cells["Prenom"].Value + " "
                    + (string)dgv_Dettes.SelectedRows[0].Cells["Nom"].Value + " paye!";
                btn_Pay.Enabled = true;
                tb_DebtPayed.Enabled = true;

                vSelectedDebts = (int)dgv_Dettes.SelectedRows[0].Cells["dette_patient"].Value;
                vSelectedDebtsSolder = (int)dgv_Dettes.SelectedRows[0].Cells["id_Patient"].Value;
            }
            catch (ArgumentOutOfRangeException) { }
        }
        /// <summary>
        /// Payement de la dette
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_Pay(object sender, EventArgs e)
        {
            int Payed;
            bool OK = Int32.TryParse(tb_DebtPayed.Text, out Payed);
            if (!OK)
            {
                MessageBox.Show("Veuillez n'entrer que des chiffres dans la case de payement!",
                    "Information", MessageBoxButtons.OK, MessageBoxIcon.Asterisk);
            }
            else
            {
                try
                {
                    if ((vSelectedDebts - Payed) < 0)
                    {
                        MessageBox.Show("Le patient paye plus qu'il ne doit.\r\nIl doit " + vSelectedDebts + " et il"
                            + " paye " + Payed + "", "Information", MessageBoxButtons.OK, MessageBoxIcon.Information);
                        return;
                    }
                    vSelectedDebts -= Payed;
                    string SQLQuery = "UPDATE PATIENT SET Dette_Patient = " + vSelectedDebts
                        + " WHERE id_Patient = " + this.vSelectedDebtsSolder + ";";
                    SqlManager.ExecuteNonQuery(SQLQuery);
                }
                catch (Exception ex)
                {
                    MessageBox.Show("Une erreur est intervenue pendant la mise  jour.\r\n" + ex.Message, "Erreur",
                            MessageBoxButtons.OK, MessageBoxIcon.Error);
                    Log.Instance.Write(ex.Message, "PhoenixMoney.GUI.fr_Main.btn_Pay_Click()", LogType.Error);
                }

                tb_DebtPayed.Text = "";
                tb_DebtPayed.Enabled = false;
                btn_Pay.Text = "Accepter";
                btn_Pay.Enabled = false;

                RefreshDettes();                
            }
        }
        #endregion

        #region Options
        /// <summary>
        /// Options changed => Set the icons size
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_OptionsChanged(object sender, EventArgs e) { SetToolStrips(); }
        #endregion
        #endregion

        #region Mthodes
        /// <summary>
        /// Rrefresh les dettes des patients
        /// </summary>
        private void RefreshDettes()
        {
            DataSet ds = new DataSet();


            try
            {
                SqlManager.ExecuteSql("SELECT * FROM Patient WHERE dette_patient > 0;", ref ds);
                dgv_Dettes.DataSource = ds.Tables[0];

                #region Affichage
                for (int i = 0; i < dgv_Dettes.Columns.Count; i++)
                    dgv_Dettes.Columns[i].Visible = false;

                dgv_Dettes.Columns["Nom"].Visible = true;
                dgv_Dettes.Columns["Nom"].HeaderText = "Nom";

                dgv_Dettes.Columns["Prenom"].Visible = true;
                dgv_Dettes.Columns["Prenom"].HeaderText = "Prnom";

                dgv_Dettes.Columns["Dette_Patient"].Visible = true;
                dgv_Dettes.Columns["Dette_Patient"].HeaderText = "Dette";
                #endregion
            }
            catch (OleDbException ex)
            {
                MessageBox.Show("Erreur au niveau de la base de donnes: "
                    + ex.Message, "Erreur", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
        /// <summary>
        /// Refresh all the data
        /// </summary>
        private void RefreshData()
        {            
            RefreshDettes();
        }
        /// <summary>
        /// Sets the size of the image of the menus
        /// </summary>
        private void SetToolStrips()
        {
            ts_Tools.AutoSize = false;
            ts_Tools.ImageScalingSize = Options.Instance.MenuImageScalingSize;
            ts_Tools.AutoSize = true;            
        }
        #endregion
    }
}